@@ -10,11 +10,11 @@ import (
 	"github.com/projectdiscovery/nuclei/v3/pkg/protocols/common/protocolstate"
 )
 
-func memoizedconnect(host string, port int, username string, password string, dbName string) (bool, error) {
+func memoizedconnect(executionId string, host string, port int, username string, password string, dbName string) (bool, error) {
 	hash := "connect" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port) + ":" + fmt.Sprint(username) + ":" + fmt.Sprint(password) + ":" + fmt.Sprint(dbName)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
-		return connect(host, port, username, password, dbName)
+		return connect(executionId, host, port, username, password, dbName)
 	})
 	if err != nil {
 		return false, err
@@ -26,11 +26,11 @@ func memoizedconnect(host string, port int, username string, password string, db
 	return false, errors.New("could not convert cached result")
 }
 
-func memoizedisMssql(host string, port int) (bool, error) {
+func memoizedisMssql(executionId string, host string, port int) (bool, error) {
 	hash := "isMssql" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
-		return isMssql(host, port)
+		return isMssql(executionId, host, port)
 	})
 	if err != nil {
 		return false, err
